
package com.redxun.knowledge.controller;

import com.redxun.common.annotation.ClassDefine;
import com.redxun.common.base.db.BaseService;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.redxun.common.base.entity.JsonResult;
import com.redxun.common.utils.ExceptionUtil;
import com.redxun.knowledge.entity.dao.KnowledgeLabel;
import com.redxun.knowledge.service.KnowledgeLabelServiceImpl;
import com.redxun.web.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/api-knowledge/knowledge/knowledgeLabel")
@Api(tags = "业务--知识标签表")
@ClassDefine(title = "业务--知识标签表", alias = "KnowledgeLabelController", path = "/api-knowledge/knowledge/knowledgeLabel", packages = "", packageName = "子系统名称")
public class KnowledgeLabelController extends BaseController<KnowledgeLabel> {

    @Autowired
    KnowledgeLabelServiceImpl knowledgeLabelService;


    @Override
    public BaseService getBaseService() {
        return knowledgeLabelService;
    }

    @Override
    public String getComment() {
        return "业务--知识标签表";
    }

    @ApiOperation(value = "新增/修改标签数据", httpMethod = "POST")
    @PostMapping("saveOrUpdateTags")
    public JsonResult saveOrUpdateTags(@RequestParam(value = "id", required = false) String id, @RequestParam(value = "name", required = true) String name, @RequestParam(value = "sort", required = true) Integer sort) {
        JsonResult jsonResult = JsonResult.getSuccessResult("请求成功!");
        try {
            KnowledgeLabel result = knowledgeLabelService.saveOrUpdateTags(id, name, sort);
            if (ObjectUtils.isEmpty(result)) {
                jsonResult.setSuccess(false);
            }
            jsonResult.setData(result);
        } catch (Exception e) {
            jsonResult.setSuccess(false);
            this.logger.error(ExceptionUtil.getExceptionMessage(e));
            jsonResult.setMessage(ExceptionUtil.getExceptionMessage(e));
        }
        return jsonResult;
    }
}

