
package com.redxun.knowledge.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.redxun.common.base.db.BaseDao;
import com.redxun.common.base.db.BaseService;
import com.redxun.common.service.impl.SuperServiceImpl;
import com.redxun.knowledge.entity.dao.KnowledgeCategory;
import com.redxun.knowledge.mapper.KnowledgeCategoryMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * [业务--知识分类表]业务服务类
 */
@Service
public class KnowledgeCategoryServiceImpl extends SuperServiceImpl<KnowledgeCategoryMapper, KnowledgeCategory> implements BaseService<KnowledgeCategory> {

    @Resource
    private KnowledgeCategoryMapper knowledgeCategoryMapper;

    @Override
    public BaseDao<KnowledgeCategory> getRepository() {
        return knowledgeCategoryMapper;
    }

    // 根据id查询其下级分类信息(懒加载)
    public KnowledgeCategory findAllByCategoryId(String categoryId) {
        QueryWrapper<KnowledgeCategory> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("PK_ID", categoryId);
        KnowledgeCategory knowledgeCategory = knowledgeCategoryMapper.selectById(categoryId);
        Boolean hasChild = findHasChirld(knowledgeCategory);
        knowledgeCategory.setHasChild(hasChild);

        if (hasChild){
            List<KnowledgeCategory> allChildren = findAllChildren(knowledgeCategory);
            knowledgeCategory.setChildren(allChildren);
            allChildren.forEach(e -> {
                Boolean hasChirld = findHasChirld(e);
                e.setHasChild(hasChirld);
            });
        } else {
            knowledgeCategory.setChildren(findAllChildren(knowledgeCategory));
        }

        return knowledgeCategory;
    }

    // 查询孩子节点
    private List<KnowledgeCategory> findAllChildren(KnowledgeCategory knowledgeCategory) {
        QueryWrapper<KnowledgeCategory> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("PARENT", knowledgeCategory.getPkId());
        List<KnowledgeCategory> knowledgeCategories = knowledgeCategoryMapper.selectList(queryWrapper);
        return knowledgeCategories;
    }

    // 判断是否有孩子节点
    private Boolean findHasChirld(KnowledgeCategory knowledgeCategory) {
        QueryWrapper<KnowledgeCategory> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("PARENT", knowledgeCategory.getPkId());
        Integer count = knowledgeCategoryMapper.selectCount(queryWrapper);
        if (count > 0) {
            return true;
        } else {
            return false;
        }
    }
}
